@@ -3,17 +3,19 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.2" or
-    raise "ruby lib version (1.8.2) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.4" or
+    raise "ruby lib version (1.8.4) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-msdosdjgpp\Z', '')
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/i386-msdosdjgpp")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.2/ruby"
+  CONFIG["INSTALL"] = "/usr/bin/install -c"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
+  CONFIG["ruby_install_name"] = "ruby"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
+  CONFIG["RUBY_SO_NAME"] = "ruby"
   CONFIG["SHELL"] = "/bin/sh"
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["PACKAGE_NAME"] = ""
@@ -34,7 +36,7 @@ module Config
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["infodir"] = "$(prefix)/info"
   CONFIG["mandir"] = "$(prefix)/man"
-  CONFIG["build_alias"] = "i586-pc-linux-gnu"
+  CONFIG["build_alias"] = "i686-pc-linux-gnu"
   CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
   CONFIG["target_alias"] = "i386-msdosdjgpp"
   CONFIG["ECHO_C"] = ""
@@ -43,9 +45,9 @@ module Config
   CONFIG["LIBS"] = "-lm "
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "2"
-  CONFIG["build"] = "i586-pc-linux-gnu"
-  CONFIG["build_cpu"] = "i586"
+  CONFIG["TEENY"] = "4"
+  CONFIG["build"] = "i686-pc-linux-gnu"
+  CONFIG["build_cpu"] = "i686"
   CONFIG["build_vendor"] = "pc"
   CONFIG["build_os"] = "linux-gnu"
   CONFIG["host"] = "i586-pc-msdosdjgpp"
@@ -57,7 +59,6 @@ module Config
   CONFIG["target_vendor"] = "pc"
   CONFIG["target_os"] = "msdosdjgpp"
   CONFIG["CC"] = "gcc"
-  CONFIG["ac_ct_CC"] = ""
   CONFIG["CFLAGS"] = "-Os"
   CONFIG["LDFLAGS"] = ""
   CONFIG["CPPFLAGS"] = ""
@@ -69,17 +70,19 @@ module Config
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["YACC"] = "bison -y"
   CONFIG["RANLIB"] = "ranlib"
-  CONFIG["ac_ct_RANLIB"] = ""
   CONFIG["AR"] = "ar"
-  CONFIG["ac_ct_AR"] = ""
   CONFIG["NM"] = ""
-  CONFIG["ac_ct_NM"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["ac_ct_WINDRES"] = ""
   CONFIG["DLLWRAP"] = ""
-  CONFIG["ac_ct_DLLWRAP"] = ""
+  CONFIG["OBJDUMP"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
+  CONFIG["INSTALL_PROGRAM"] = "$(INSTALL)"
+  CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
+  CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
+  CONFIG["RM"] = "rm -f"
+  CONFIG["CP"] = "cp"
+  CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["LIBOBJS"] = " fileblocks$(U).o crypt$(U).o flock$(U).o vsnprintf$(U).o"
   CONFIG["ALLOCA"] = ""
   CONFIG["DLDFLAGS"] = ""
@@ -93,22 +96,23 @@ module Config
   CONFIG["LINK_SO"] = ""
   CONFIG["LIBPATHFLAG"] = " -L\"%s\""
   CONFIG["RPATHFLAG"] = ""
+  CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
   CONFIG["TRY_LINK"] = ""
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.2/d.obj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.4/d.obj -rfake"
   CONFIG["PREP"] = "fake.rb"
+  CONFIG["RUNRUBY"] = "$(MINIRUBY) -I`cd $(srcdir)/lib; pwd`"
+  CONFIG["EXTOUT"] = ".ext"
   CONFIG["ARCHFILE"] = ""
   CONFIG["RDOCTARGET"] = ""
-  CONFIG["XCFLAGS"] = ""
+  CONFIG["XCFLAGS"] = " -DRUBY_EXPORT"
   CONFIG["XLDFLAGS"] = " -L."
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
   CONFIG["rubyw_install_name"] = ""
   CONFIG["RUBYW_INSTALL_NAME"] = ""
-  CONFIG["RUBY_SO_NAME"] = "$(RUBY_INSTALL_NAME)"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
@@ -124,36 +128,34 @@ module Config
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
+  CONFIG["MINIOBJS"] = ""
   CONFIG["MAKEFILES"] = "Makefile"
   CONFIG["arch"] = "i386-msdosdjgpp"
   CONFIG["sitearch"] = "i386-msdosdjgpp"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-msdosdjgpp' '--host=i586-pc-msdosdjgpp' '--build=i586-pc-linux-gnu' '--with-gcc=gcc' '--with-bundled-md5' 'CXX=g++' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i586-pc-msdosdjgpp' 'target_alias=i386-msdosdjgpp'"
+  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-msdosdjgpp' '--host=i586-pc-msdosdjgpp' '--build=i686-pc-linux-gnu' '--with-gcc=gcc' '--with-bundled-md5' 'CXX=g++' 'CFLAGS=-Os' 'build_alias=i686-pc-linux-gnu' 'host_alias=i586-pc-msdosdjgpp' 'target_alias=i386-msdosdjgpp'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["LTLIBOBJS"] = " fileblocks$(U).lo crypt$(U).lo flock$(U).lo vsnprintf$(U).lo"
-  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
-  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
-  CONFIG["builddir"] = "$(ac_builddir)"
-  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
-  CONFIG["top_builddir"] = "$(ac_top_builddir)"
-  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
-  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.2/d.obj"
+  CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val, config = CONFIG)
     val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
       if !(v = $1 || $2)
 	'$'
-      elsif key = config[v]
+      elsif key = config[v = v[/\A[^:]+(?=(?::(.*?)=(.*))?\z)/]]
+	pat, sub = $1, $2
 	config[v] = false
-        Config::expand(key, config)
+	Config::expand(key, config)
 	config[v] = key
+	key = key.gsub(/#{Regexp.quote(pat)}(?=\s|\z)/n) {sub} if pat
+	key
       else
 	var
       end
